import { Test, TestingModule } from '@nestjs/testing';
import { DnsService } from './dns.service';
import * as dns from 'dns';

jest.mock('dns', () => ({
  lookup: jest.fn(),
}));

describe('DnsService', () => {
  let service: DnsService;
  let dnsLookupMock: jest.Mock;

  beforeEach(async () => {
    const module: TestingModule = await Test.createTestingModule({
      providers: [DnsService],
    }).compile();

    service = module.get<DnsService>(DnsService);
    dnsLookupMock = (dns.lookup as unknown) as jest.Mock;
  });

  it('should return true for a valid URL', async () => {
    dnsLookupMock.mockImplementation((hostname, callback) => callback(null, '1.1.1.1'));
    expect(await service.isValidUrl('http://example.com')).toBe(true);
  });

  it('should return false for an invalid URL', async () => {
    dnsLookupMock.mockImplementation((hostname, callback) => callback(new Error('not found'), null));
    expect(await service.isValidUrl('http://invalid-url.com')).toBe(false);
  });
});