import { Controller, Post, Body, Get, Param, HttpException, HttpStatus, Res } from '@nestjs/common';
import { UrlShortenerService } from './url-shortener.service';
import { ApiResponse } from './response.interface';
import { Response } from 'express';
import { ConfigService } from '@nestjs/config';


@Controller('url-shortener')
export class UrlShortenerController {
  constructor(private readonly urlShortenerService: UrlShortenerService, private configService: ConfigService) {}

  @Post('shorten')
  async shortenUrl(@Body('url') url: string): Promise<ApiResponse> {
    if (!url) {
      throw new HttpException('URL is required', HttpStatus.BAD_REQUEST);
    }
    try {
      const shortUrl = await this.urlShortenerService.generateShortUrl(url);
      return { data: shortUrl, status: HttpStatus.CREATED };
    } catch (error) {
      return { error: error.message, status: HttpStatus.BAD_REQUEST };
    }
  }

  @Get(':shortUrl')
  async resolveShortUrl(@Param('shortUrl') shortUrl: string, @Res() res: Response) {
    try {
      const originalUrl = this.urlShortenerService.getOriginalUrl(shortUrl);
      if (!originalUrl) {
        return res.redirect(`${this.configService.get<string>('UI_URL')}/404`);
      }
      return res.redirect(originalUrl);
    } catch (error) {
      throw new HttpException('An error occurred', HttpStatus.INTERNAL_SERVER_ERROR);
    }
  }
}