import { Test, TestingModule } from '@nestjs/testing';
import { UrlShortenerService } from './url-shortener.service';
import { DnsService } from '../dns/dns.service';

describe('UrlShortenerService', () => {
  let service: UrlShortenerService;
  let dnsService: DnsService;

  beforeEach(async () => {
    const module: TestingModule = await Test.createTestingModule({
      providers: [
        UrlShortenerService,
        { provide: DnsService, useValue: { isValidUrl: jest.fn().mockResolvedValue(true) } },
      ],
    }).compile();

    service = module.get<UrlShortenerService>(UrlShortenerService);
    dnsService = module.get<DnsService>(DnsService);
  });

  it('should be defined', () => {
    expect(service).toBeDefined();
  });

  it('should generate and retrieve a short URL', async () => {
    jest.spyOn(dnsService, 'isValidUrl').mockResolvedValue(true);
    const url = 'https://example.com';
    const shortUrl = await service.generateShortUrl(url);
    expect(shortUrl).toBeDefined();
    expect(await service.getOriginalUrl(shortUrl)).toBe(url);
  });

  it('should throw an error for an invalid URL', async () => {
    jest.spyOn(dnsService, 'isValidUrl').mockResolvedValue(false);
    const url = 'http://invalid-url';
  
    await expect(service.generateShortUrl(url)).rejects.toThrow('URL is invalid');
  });

});
